#
# spec file for package perl-Module-Build
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Module-Build
Name:           perl-Module-Build
Version:        0.423400
Release:        1.7
%define cpan_version 0.4234
Provides:       perl(Module::Build) = 0.423400
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Build and install Perl modules
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/L/LE/LEONT/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(CPAN::Meta) >= 2.142060
BuildRequires:  perl(CPAN::Meta::YAML) >= 0.003
BuildRequires:  perl(ExtUtils::CBuilder) >= 0.27
BuildRequires:  perl(ExtUtils::ParseXS) >= 2.21
BuildRequires:  perl(Module::Metadata) >= 1.000002
BuildRequires:  perl(Parse::CPAN::Meta) >= 1.4401
BuildRequires:  perl(Perl::OSType) >= 1
BuildRequires:  perl(TAP::Harness) >= 3.29
BuildRequires:  perl(version) >= 0.87
Requires:       perl(CPAN::Meta) >= 2.142060
Requires:       perl(ExtUtils::CBuilder) >= 0.27
Requires:       perl(ExtUtils::ParseXS) >= 2.21
Requires:       perl(Module::Metadata) >= 1.000002
Requires:       perl(Perl::OSType) >= 1
Requires:       perl(TAP::Harness) >= 3.29
Requires:       perl(version) >= 0.87
Recommends:     perl(ExtUtils::Manifest) >= 1.54
%{perl_requires}

%description
'Module::Build' is a system for building, testing, and installing Perl
modules. It is meant to be an alternative to 'ExtUtils::MakeMaker'.
Developers may alter the behavior of the module through subclassing. It
also does not require a 'make' on your system - most of the 'Module::Build'
code is pure-perl and written in a very cross-platform way.

See "COMPARISON" for more comparisons between 'Module::Build' and other
installer tools.

To install 'Module::Build', and any other module that uses 'Module::Build'
for its installation process, do the following:

  perl Build.PL       # 'Build.PL' script creates the 'Build' script
  ./Build             # Need ./ to ensure we're using this "Build" script
  ./Build test        # and not another one that happens to be in the PATH
  ./Build install

This illustrates initial configuration and the running of three 'actions'.
In this case the actions run are 'build' (the default action), 'test', and
'install'. Other actions defined so far include:

  build                          manifest
  clean                          manifest_skip
  code                           manpages
  config_data                    pardist
  diff                           ppd
  dist                           ppmdist
  distcheck                      prereq_data
  distclean                      prereq_report
  distdir                        pure_install
  distinstall                    realclean
  distmeta                       retest
  distsign                       skipcheck
  disttest                       test
  docs                           testall
  fakeinstall                    testcover
  help                           testdb
  html                           testpod
  install                        testpodcoverage
  installdeps                    versioninstall

You can run the 'help' action for a complete list of actions.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Build.PL installdirs=vendor
./Build build flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
# MANUAL BEGIN
# avoid conflict with Perl's own supplied version
mv %{buildroot}/usr/bin/config_data %{buildroot}/usr/bin/config_data-%{version}
rename config_data config_data-%{version} %{buildroot}/%{_mandir}/man1/config_data.*
# MANUAL END
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Sat Apr 29 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.4234
  see /usr/share/doc/packages/perl-Module-Build/Changes
  0.4234 - Fri 28 Apr 2023 10:46:26 CEST
  - PodParser now respects =encoding directives
  - Don't use libraries in t/bundled for Build.PL
  - make_tarball: workaround for broken tar on Darwin
  - Respect $Config{man1ext}/$Config{man3ext}
  - Do not require a compiler if c_source is an empty list
  0.42_33 - Wed Mar 29 10:38:56 PM CEST 2023
  - PodParser now respects =encoding directives
  - Don't use libraries in t/bundled for Build.PL
  - make_tarball: workaround for broken tar on Darwin
  - Respect $Config{man1ext}/$Config{man3ext}
  - Do not require a compiler if c_source is an empty list
* Fri Dec  9 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.4232
  see /usr/share/doc/packages/perl-Module-Build/Changes
  0.4232 - Thu Dec  8 10:27:44 PM CET 2022
  - Drop Pod::Man dependency for 5.8 compatibility
* Thu Jan 30 2020 <timueller+perl@suse.de>
- updated to 0.4231
  see /usr/share/doc/packages/perl-Module-Build/Changes
  0.4231 - Wed Jan 29 08:47:56 CET 2020
  - Released 0.42_30 without code changes
  0.42_30 - Wed Jul 31 13:15:39 CEST 2019
  - Add dependency on ExtUtils::PL2Bat
* Tue Apr 16 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.4229
  see /usr/share/doc/packages/perl-Module-Build/Changes
  0.4229 - Tue Apr 16 00:49:45 CEST 2019
  - Released 0.42_28 without changes
  0.42_28 - Thu Apr 19 16:34:32 CEST 2018
  - Replace "MOTIVATIONS" section with "COMPARISON" [Dan Brook]
  - Update configure, build, test prereqs [Karen Etheridge]
  0.4227 - Wed Dec 13 11:17:51 CET 2017
  - Released 0.42_26 without changes
  0.42_26 - Wed Dec 13 10:52:39 CET 2017
  - Improve pureperl-only support (#119914) [Shoichi Kaji]
  - Improve the documentation of Module::Build::Compat and dynamic_config [Dan Brook]
* Wed May 31 2017 coolo@suse.com
- updated to 0.4224
  see /usr/share/doc/packages/perl-Module-Build/Changes
  0.4224 - Tue May 30 19:50:07 CEST 2017
  - Released 0.42_23 without changes
  0.42_23 - Sun May 14 13:17:45 CEST 2017
  - Add code to special case dot-in-inc in Build
* Fri Mar 31 2017 coolo@suse.com
- updated to 0.4222
  see /usr/share/doc/packages/perl-Module-Build/Changes
  0.4222 - Thu Mar 30 15:40:10 CEST 2017
  - Released 0.42_21 as 0.4222
  0.42_21 - Wed Mar 22 19:04:02 CET 2017
  - Include relative path for do in Build/Makefile.PL will function without . in @INC [Todd Rinaldo]
  - Remove use deprecate [Graham Knop]
* Wed Aug 17 2016 coolo@suse.com
- updated to 0.4220
  see /usr/share/doc/packages/perl-Module-Build/Changes
  0.4220 - Tue Aug 16 22:11:14 CEST 2016
  - Released 0.42_19 as 0.4220
  0.42_19 - Sun Aug  7 17:07:38 CEST 2016
  - Initialize MM Compat environmental variables to empty strings [Leon Timmermans]
  - Skip PPM test when link_executable fails [Leon Timmermans]
  - Make more actions deterministic [Zefram]
  - Preprocess file lists generated by rscan_dir() to sort them [Niko Tyni]
* Tue May 10 2016 coolo@suse.com
- updated to 0.4218
  see /usr/share/doc/packages/perl-Module-Build/Changes
  0.4218 - Sun Apr 24 16:39:47 BST 2016
  - Skip XS test when link_executable fails
  0.42_17 - Mon Mar 21 14:02:06 CET 2016
  - Read extra_linker_flags using its accessor [Salvador Fandino]
  - Convert win shell splitting to m//gc parser, fixing handling of 0
    and handling of backslashes preceeding a double quote [Graham Knop]
  - Win32 installation of MB with gmake require SHELL env var to be set
    [bulk88]
  0.4216 - Wed Jan 20 10:39:27 CET 2016
  - Delete test that fails with new version.pm [Leon Timmermans]
  0.42_15 - Sat Nov 28 15:17:40 CET 2015
  - Honor environmental variables when using TAP::Harness directly [Leon Timmermans]
  - Reintroduce some level of perl 5.6 support [Leon Timmermans]
    Note that this comes with no guarantees or commitment
  - Allow Devel::Cover usage with TAP::Harness [Philipp Gortan]
  - Remove "running under some shell" [Shoichi Kaji]
  - Fix cookbook - code was missing trailing ` [Matthew Horsfall]
  0.4214 - Fri Jun 12 00:25:00 CEST 2015
  - Released 0.42_13 as 0.4214
  0.42_13 - Sat Jun  6 21:18:24 CEST 2015
    [BUG FIXES]
  - Handle failure to guess license from key better
    [ENHANCEMENTS]
  - Output data in a stable order [Jérémy Bobbio]
- deleted patch make-builds-reproducible.patch
* Sun May 17 2015 coolo@suse.com
- updated to 0.4212
  see /usr/share/doc/packages/perl-Module-Build/Changes
  0.4212 - Sun May 17 00:33:34 CEST 2015
    [BUG FIXES]
  - Revert "Stop using version->normal(); prefer stringify()"
* Thu Apr 16 2015 coolo@suse.com
- expanding the version to 6 digits after . - to avoid version mismatches
* Tue Feb  3 2015 coolo@suse.com
- add make-builds-reproducible.patch to sort the config data
* Tue Feb  3 2015 coolo@suse.com
- updated to 0.4211
  [BUG FIXES]
  - Fix t/actions/installdeps.t to work on "perl in space" [Ed J]
  - Stop using version->normal(); prefer stringify() [John Peacock]
  [DEPRECATIONS]
  - inc::latest has been split out to a separate distribution on CPAN.
    It is an optional prerequisite, only needed for the experimental
    bundling feature.
* Sun Dec 21 2014 lars@linux-schulserver.de
- update to 0.4210:
  [BUG FIXES]
  - Formally declare 5.8 dependency [Karen Etheridge]
  - Fix MBTest to work with new and old versions of Test::Builder [Chad Granum]
  - Fix type installdir -> installdirs [Leon Timmermans, Vitaliy Tokarev]
  - Removed missed references to Module::Build::Version
  - Stop calling UNIVERSAL::isa as a function
  - Fixup CPAN::Meta dependency
  - Handle old releases of CPAN::Meta more gracefully.
  [ENHANCEMENTS]
  - Enable release and author tests during disttest [Leon Timmermans, Alberto Simões]
  - Use CPAN::Meta::Merge for meta_merge
  - Convert with CPAN::Meta::Convert in meta_add
  - Add configure requirements
  [DEPRECATIONS]
  - Module::Build::YAML has been removed
  - Module::Build::ModuleInfo has been removed
  - Module::Build::Version has been removed
  - Get rid of "use vars"
  - Added use warnings to all modules
- use local lib in lib/Module/Build/Base.pm
* Sun Feb 16 2014 lars@linux-schulserver.de
- update to 0.4205:
  [BUG FIXES]
  - FIX license code regression for artistic license
  - Don't swallow ExtUtils::CBuilder loading errors
  - Handle testing on cross-compile builds
  - Protect against platforms without getpw{nam,uid}
* Fri Jan 17 2014 lars@linux-schulserver.de
- update to 0.4204:
  [BUG FIXES]
  - Map conflicts back to runtime [Leon Timmermans]
  - Use mod2fname whenever it's available [Leon Timmermans, Brian Fraser]
  - Accept custom entries in meta_merge 1.4
* Tue Dec 10 2013 coolo@suse.com
- updated to 0.4203
  [BUG FIXES]
  - Map recommends back to runtime recommends [Leon Timmermans]
  - Map restrictive license to restricted in meta 2.0 [Leon Timmermans]
  - Don't merge prereqs from meta to mymeta [Leon Timmermans]
  - Prefer META.json over META.yml [Leon Timmermans]
  - Do not set provides in metadata if no_index is set [Leon Timmermans]
  - Lowercase license in fallback logic [Leon Timmermans]
  [ENHANCEMENTS]
  - Converted to using Meta 2.0
* Tue Oct  8 2013 coolo@suse.com
- updated to 0.4007
  [BUG FIXES]
  - Removed undeclared test dependency on parent.pm [Leon Timmermans]
  - Declared dependency on Pod::Man 2.17 for utf8 support [Leon Timmermans]
  - Force generation of man pages in manify_with_utf8.t [Leon Timmermans]
  0.4006 - Thu Jul 18 14:19:49 CEST 2013
  [ENHANCEMENTS]
  - Significantly sped up some tests by not forcing HTML docs to be
    built when the user's config doesn't ask for them anyway.
    [Ken Williams]
  - The Module::Metadata package was split out from this distro back
    in 2010.  Removed its regression tests. [Ken Williams]
  - Removed dependence on IO::File, replacing it with safe invocations
    of open(). [Sven Dowideit]
  - Added an 'extra_manify_args' parameter to facilitate man pages
    containing Unicode. [Joenio Costa]
  - Added an '--html_links 0' argument for the 'html' action, which
    can hugely speed things up.  The main effect is speeding up the
    M::B tests themselves. [Ken Williams]
  [BUG FIXES]
  - Fix hash argument parsing in subclasses [Graham Ollis]
  - Revised detildification on VMS [Craig Berry]
  - Fix run_test_harness for case when $Switches is an empty string
    [Victor Efimov, Ken Williams]
* Thu Jun 27 2013 coolo@suse.com
- add more of the required modules
* Thu Jun 27 2013 lnt-sysadmin@lists.lrz.de
- added perl(Module::Metadata) as dependency
* Tue Jun 11 2013 coolo@suse.com
- updated to 0.4005
  [ENHANCEMENTS]
  - Added --pureperl-only support
  [BUG FIXES]
  - #72176: pod2html will fail with an empty podpath in some cases. [Phillip Moore]
  - Fix links between modules in HTML docs output [Michael Wild, Leon Timmermans]
  [BUG FIXES]
  - Minor VMS fix for @INC [Craig Berry]
  [ENHANCEMENTS]
  - test_requires support has been added [Matsuno Tokuhiro]
* Thu Oct 25 2012 opensuse@dstoecker.de
- fix requirements for building on older suse versions
* Wed Sep 19 2012 opensuse@dstoecker.de
- update to 0.4003
* Wed Aug 17 2011 chris@computersalat.de
- fix deps for RHEL, CentOS
* Fri Dec  3 2010 seife@opensuse.org
- change version to 0.36.07 to prevent rpm version compare problems
* Thu Dec  2 2010 seife@opensuse.org
- fix conflict of config_data with the perl-supplied one by
  renaming it to config_data-${version}
* Thu Dec  2 2010 seife@opensuse.org
- update to 0.3607. Fixes:
  - The 'dist' action now always ensures a clean dist directory
    before creating the tarball
  - Added missing newline to "Changing sharpbang" messages under
    verbose output (RT#54474)
  - Support anonymous array of directories for c_source
  - Small POD formatting fix
  - Module::Build::Compat would croak on distibutions that set
    requires 'perl' to a dotted decimal like '5.6.2'.
  - When the currently running Module::Build is not the same as the
    one that created the Build file, there is now a warning rather
    than a fatal error.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Tue Sep 14 2010 chris@computersalat.de
- update to 0.36
  o just for SLE_10 :)
- noarch pkg
* Thu Mar  4 2010 chris@computersalat.de
- add again obviously removed package
  o BuildReq by e.g. Test::Pod for SLE_10
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Mon Jun 22 2009 chris@computersalat.de
- initial package 0.31
